#
# spec file for package python-nltk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_module:%define python_module() python-%{**} python3-%{**}}
%define interps python python3

%define pyname nltk
Name:           python-nltk
Version:        3.2.5
Release:        lp150.2.1
Summary:        Natural Language Toolkit
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://nltk.org/
Source:         https://files.pythonhosted.org/packages/source/n/nltk/%{pyname}-%{version}.tar.gz
BuildRequires:  %{interps}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-gensim
Recommends:     python-matplotlib
Recommends:     python-numpy
Recommends:     python-pyparsing
Recommends:     python-requests
Recommends:     python-scipy
BuildArch:      noarch
%python_subpackages

%description
NLTK -- the Natural Language Toolkit -- is a suite of
Python modules, data sets and tutorials supporting research and
development in Natural Language Processing.

%prep
%setup -q -n %{pyname}-%{version}

sed -i "1,4{/\/usr\/bin\/env/d}" nltk/corpus/reader/knbc.py
sed -i "1,4{/\/usr\/bin\/env/d}" nltk/test/runtests.py
sed -i "1,4{/\/usr\/bin\/env/d}" nltk/test/unit/test_tgrep.py
sed -i "1,4{/\/usr\/bin\/env/d}" nltk/tgrep.py
sed -i "1,4{/\/usr\/bin\/env/d}" nltk/tokenize/stanford_segmenter.py

%build
%python_build

%install
%python_install

%{python_expand %fdupes -s %{buildroot}%{$python_sitelib}/
chmod -x %{buildroot}%{$python_sitelib}/nltk/test/dependency.doctest
}

%check
# FOLLOWING http://www.nltk.org/install.html
%python_exec -c "import nltk" || exit 1

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/%{pyname}/
%{python_sitelib}/%{pyname}-%{version}-py%{py_ver}.egg-info/

%changelog
* Tue Mar  6 2018 jengelh@inai.de
- Trim redundant wording from description.
* Mon Mar  5 2018 badshah400@gmail.com
- Use \%%license instead of \%%doc to install License.txt.
* Tue Jan 30 2018 guigo.lourenco@gmail.com
- Depend on the full python interpreter to fix sqlite3 import
  during %%check
* Tue Jan 16 2018 guigo.lourenco@gmail.com
- Depend on python-rpm-macros
- Build for both Python2 and Python3
* Tue Dec 19 2017 badshah400@gmail.com
- Update to version 3.2.5:
  * Arabic stemmers (ARLSTem, Snowball)
  * NIST MT evaluation metric and added NIST
    international_tokenize
  * Moses tokenizer
  * Document Russian tagger
  * Fix to Stanford segmenter
  * Improve treebank detokenizer, VerbNet, Vader
  * Misc code and documentation cleanups
  * Implement fixes suggested by LGTM
- Convert specfile to python single-spec style.
- Drop unneeded BuildRequires: python-PyYAML, python-xml,
  python-devel; not required for building.
- Change existing Requires to Recommends: these are really needed
  for additional features, and not required for basic nltk usage.
- Add new Recommends: python-scipy, python-matplotlib,
  python-pyparsing, and python-gensim; enables other optional
  features.
- Run fdupes to link-up duplicate files.
- Remove exec permissions for a file not intended to be executed
  (not in exec path, no hashbang, etc.)
- Remove hashbangs from non-executable files.
- Run tests following the suggestion from
  http://www.nltk.org/install.html.
* Tue Feb 21 2017 stephan.barth@suse.com
- update to version 3.2.2
  Upstream changelog:
  Support for Aline, ChrF and GLEU MT evaluation metrics, Russian POS tagger
  model, Moses detokenizer, rewrite Porter Stemmer and FrameNet corpus reader,
  update FrameNet Corpus to version 1.7, fixes: stanford_segmenter.py,
  SentiText, CoNLL Corpus Reader, BLEU, naivebayes, Krippendorff’s alpha,
  Punkt, Moses tokenizer, TweetTokenizer, ToktokTokenizer; improvements to
  testing framework
* Fri Oct 14 2016 toddrme2178@gmail.com
- Update to version 3.2.1
  + No changelog available
* Thu May 21 2015 toddrme2178@gmail.com
- Remove upstreamed nltk-2.0.4-dont-use-python-distribute.patch
- Update to version 3.0.2
  + No changelog available
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 2.0.4
  + No changelog available
- Add nltk-2.0.4-dont-use-python-distribute.patch ; force use of
  python-setuptools instead of python-distribute
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 2.0.1rc1
* Mon Feb  8 2010 oddrationale@gmail.com
- fixed copyright and license statements
- removed PyYAML, and added dependency to installers and download
  instructions
- updated to LogicParser, DRT (Dan Garrette)
- WordNet similarity metrics return None instead of -1 when
  they fail to find a path (Steve Bethard)
- shortest_path_distance uses instance hypernyms (Jordan
  Boyd-Graber)
- clean_html improved (Bjorn Maeland)
- batch_parse, batch_interpret and batch_evaluate functions allow
  grammar or grammar filename as argument
- more Portuguese examples (portuguese_en.doctest, examples/pt.py)
* Thu Dec 10 2009 oddrationale@gmail.com
- added python-nltk-remove-yaml.patch to pevent conflict with
  python-yaml
- added Requires: python-yaml
* Wed Dec  9 2009 oddrationale@gmail.com  
- Initial Release (Version 2.0b7): Sun Feb  7 18:50:18 CST 2010
